@@ -4,10 +4,11 @@ rocks_trees = {
    { name = "user", root = home .. "/.luarocks" };
    { name = "system", root = "/usr/local" };
 }
-lua_interpreter = "lua52";
 variables = {
    LUA_DIR = "/usr/local";
    LUA_INCDIR = "/usr/local/include/lua-5.2";
    LUA_BINDIR = "/usr/local/bin";
    LUA_LIBDIR = "/usr/local/lib";
+   LUA_VERSION = "5.2";
+   LUA = "/usr/local/bin/lua52";
 }
